@@ -12,7 +12,7 @@
 
 from gi.repository import Gtk, GLib
 
-from lollypop.define import App, SidebarContent, Type
+from lollypop.define import App, SidebarContent, Type, ViewType
 from lollypop.view import View
 from lollypop.adaptive import AdaptiveStack
 from lollypop.container_notification import NotificationContainer
@@ -30,9 +30,10 @@ class Container(Gtk.Overlay, NotificationContainer,
         Main view management
     """
 
-    def __init__(self):
+    def __init__(self, view_type=ViewType.DEFAULT):
         """
             Init container
+            @param view_type as ViewType, will be appended to any created view
         """
         Gtk.Overlay.__init__(self)
         NotificationContainer.__init__(self)
@@ -40,11 +41,12 @@ class Container(Gtk.Overlay, NotificationContainer,
         PlaylistsContainer.__init__(self)
         ListsContainer.__init__(self)
         ViewsContainer.__init__(self)
+        self._view_type = view_type
         self._rounded_artists_view = None
         self._stack = AdaptiveStack()
         self._stack.show()
         self.__setup_view()
-        self.add(self.__paned_one)
+        self.add(self._paned_one)
 
     def stop_all(self):
         """
@@ -59,9 +61,9 @@ class Container(Gtk.Overlay, NotificationContainer,
             Reload current view
         """
         if App().settings.get_value("show-sidebar"):
-            self._reload_list_view()
+            ListsContainer._restore_state(self)
         else:
-            self._reload_navigation_view()
+            ViewsContainer._restore_state(self)
 
     def show_sidebar(self, show):
         """
@@ -69,64 +71,73 @@ class Container(Gtk.Overlay, NotificationContainer,
             @param show as bool
         """
         def select_list_one(selection_list):
-            self._reload_list_view()
+            ListsContainer._restore_state(self)
             self._list_one.disconnect_by_func(select_list_one)
 
-        adaptive_window = App().window.is_adaptive
         if self._rounded_artists_view is not None:
-            self._rounded_artists_view.make_destroyable()
+            self._rounded_artists_view.destroy()
             self._rounded_artists_view = None
-        if show or adaptive_window:
-            if not adaptive_window:
-                App().window.emit("show-can-go-back", False)
+
+        if show:
+            self._setup_lists()
             self._list_one.show()
-            if self._list_one.count == 0:
-                self._list_one.connect("populated", select_list_one)
-                self.update_list_one()
+            if len(self._stack.get_children()) == 1:
+                App().window.emit("can-go-back-changed", False)
+            self._list_one.connect("populated", select_list_one)
+            self.update_list_one()
+            self.__show_settings_dialog()
+        else:
+            if self._list_one is not None:
+                self._list_one.destroy()
+                self._list_two.destroy()
+                self._list_one = self._list_two = None
+            App().window.emit("show-can-go-back", True)
+            empty = len(self._stack.get_children()) == 0
+            App().window.emit("can-go-back-changed", not empty)
+            # Remove any existing child
+            children = self._stack.get_children()
+            for child in children:
+                self._stack.remove(child)
+            # Be sure to have an initial artist view
+            if self._rounded_artists_view is None:
+                self._rounded_artists_view = self._get_view_artists_rounded(
+                    True)
+                self._stack.set_visible_child(self._rounded_artists_view)
+            if empty:
+                ViewsContainer._restore_state(self)
             else:
-                # Show settings dialog
-                from lollypop.view_settings import SettingsChildView
-                from lollypop.view_settings import SettingsView
-                if isinstance(self.view, SettingsChildView) or\
-                        isinstance(self.view, SettingsView):
-                    action = App().lookup_action("settings")
-                    GLib.idle_add(action.activate,
-                                  GLib.Variant("i", self.view.type))
-                self._reload_list_view()
-        elif not adaptive_window:
-            if self._list_one.get_visible():
-                self._list_two.hide()
-                self._list_one.hide()
-            from lollypop.view_search import SearchView
-            for child in self._stack.get_children():
-                if type(child) != SearchView:
-                    child.destroy()
-            self._reload_navigation_view()
+                # Add children now we have an initial artist view
+                for child in children:
+                    self._stack.add(child)
+                    self._stack.set_visible_child(child)
 
     def show_artists_albums(self, artist_ids):
         """
             Show albums from artists
             @param artist_ids as [int]
         """
-        def select_list_two(selection_list, artist_ids):
-            self._list_two.select_ids(artist_ids)
-            self._list_two.disconnect_by_func(select_list_two)
         sidebar_content = App().settings.get_enum("sidebar-content")
-        if sidebar_content == SidebarContent.GENRES:
-            # Get artist genres
-            genre_ids = []
-            for artist_id in artist_ids:
-                album_ids = App().artists.get_albums(artist_ids)
-                for album_id in album_ids:
-                    for genre_id in App().albums.get_genre_ids(album_id):
-                        if genre_id not in genre_ids:
-                            genre_ids.append(genre_id)
-            self.show_lists(genre_ids, artist_ids)
-        elif sidebar_content == SidebarContent.ARTISTS:
-            # Select artists on list one
-            self.show_lists(artist_ids, [])
+        if App().settings.get_value("show-sidebar") and\
+                not sidebar_content == SidebarContent.DEFAULT and\
+                not App().window.is_adaptive:
+            if sidebar_content == SidebarContent.GENRES:
+                # Get artist genres
+                genre_ids = []
+                for artist_id in artist_ids:
+                    album_ids = App().artists.get_albums(artist_ids)
+                    for album_id in album_ids:
+                        for genre_id in App().albums.get_genre_ids(album_id):
+                            if genre_id not in genre_ids:
+                                genre_ids.append(genre_id)
+                self.show_lists(genre_ids, artist_ids)
+            elif sidebar_content == SidebarContent.ARTISTS:
+                # Select artists on list one
+                self.show_lists(artist_ids, [])
         else:
-            self.show_view(artist_ids)
+            if sidebar_content == SidebarContent.DEFAULT and\
+                    self._stack.get_children():
+                App().window.emit("show-can-go-back", True)
+            self.show_view([Type.ARTISTS], artist_ids)
 
     @property
     def view(self):
@@ -147,20 +158,6 @@ class Container(Gtk.Overlay, NotificationContainer,
         """
         return self._stack
 
-    @property
-    def paned_one(self):
-        """
-            Get first paned (list_one)
-        """
-        return self.__paned_one
-
-    @property
-    def paned_two(self):
-        """
-            Get second paned (list_two)
-        """
-        return self.__paned_two
-
     @property
     def progress(self):
         """
@@ -169,6 +166,14 @@ class Container(Gtk.Overlay, NotificationContainer,
         """
         return self.__progress
 
+    @property
+    def rounded_artists_view(self):
+        """
+            Get rounder artists view
+            @return RoundedArtistsView
+        """
+        return self._rounded_artists_view
+
 ############
 # PRIVATE  #
 ############
@@ -179,33 +184,39 @@ class Container(Gtk.Overlay, NotificationContainer,
                 - artist list
                 - main view as artist view or album view
         """
-        self.__paned_one = Gtk.Paned.new(Gtk.Orientation.HORIZONTAL)
-        self.__paned_two = Gtk.Paned.new(Gtk.Orientation.HORIZONTAL)
+        self._paned_one = Gtk.Paned.new(Gtk.Orientation.HORIZONTAL)
+        self._paned_two = Gtk.Paned.new(Gtk.Orientation.HORIZONTAL)
 
-        self.__paned_one.connect("notify::position", self.__on_paned_position)
-        self.__paned_two.connect("notify::position", self.__on_paned_position)
+        self._paned_one.connect("notify::position", self.__on_paned_position)
+        self._paned_two.connect("notify::position", self.__on_paned_position)
 
         self.__progress = ProgressBar()
         self.__progress.get_style_context().add_class("progress-bottom")
         self.__progress.set_property("valign", Gtk.Align.END)
         self.add_overlay(self.__progress)
 
-        self.__paned_two.add1(self._list_two)
-        self.__paned_two.add2(self._stack)
-        self.__paned_one.add1(self._list_one)
-        self.__paned_one.add2(self.__paned_two)
-        position1 = App().settings.get_value(
+        self._paned_two.add2(self._stack)
+        self._paned_one.add2(self._paned_two)
+        position = App().settings.get_value(
             "paned-mainlist-width").get_int32()
-        position2 = App().settings.get_value(
-            "paned-listview-width").get_int32()
-        self.__paned_one.set_position(position1)
-        # GTK does not like paned inside paned set_position()
-        GLib.timeout_add(100, self.__paned_two.set_position, position2)
-        self.__paned_one.show()
-        self.__paned_two.show()
+        self._paned_one.set_position(position)
+        self._paned_one.show()
+        self._paned_two.show()
         search_action = App().lookup_action("search")
         search_action.connect("activate", self.__on_search_activate)
 
+    def __show_settings_dialog(self):
+        """
+            Show settings dialog if view exists in stack
+        """
+        from lollypop.view_settings import SettingsChildView
+        from lollypop.view_settings import SettingsView
+        if isinstance(self.view, SettingsChildView) or\
+                isinstance(self.view, SettingsView):
+            action = App().lookup_action("settings")
+            GLib.idle_add(action.activate,
+                          GLib.Variant("i", self.view.type))
+
     def __on_search_activate(self, action, variant):
         """
             @param action as Gio.SimpleAction
@@ -222,12 +233,14 @@ class Container(Gtk.Overlay, NotificationContainer,
             @param param as GParamSpec
         """
         position = paned.get_property(param.name)
-        if paned == self.__paned_one:
+        # We do not want to save position while adaptive mode is set
+        # Not a good a fix but a working one
+        if position < 100:
+            return
+        if paned == self._paned_one:
             setting = "paned-mainlist-width"
         else:
             setting = "paned-listview-width"
-        if position < 100:
-            position = 100
         App().settings.set_value(setting,
                                  GLib.Variant("i",
                                               position))
