@@ -52,65 +52,63 @@ class ViewsContainer:
             @param data as object
             @param switch as bool
         """
-        if not item_ids:
-            return
         App().window.emit("can-go-back-changed", True)
-        if item_ids[0] in [Type.POPULARS,
-                           Type.LOVED,
-                           Type.RECENTS,
-                           Type.NEVER,
-                           Type.RANDOMS,
-                           Type.WEB]:
-            view = self._get_view_albums(item_ids, [])
-        elif item_ids[0] == Type.SEARCH:
-            view = self.get_view_search(data)
-        elif item_ids[0] == Type.INFO:
-            view = self._get_view_info()
-        elif item_ids[0] == Type.DEVICE_ALBUMS:
-            view = self._get_view_device_albums(data)
-        elif item_ids[0] == Type.DEVICE_PLAYLISTS:
-            view = self._get_view_device_playlists(data)
-        elif item_ids[0] == Type.GENRES:
-            if data is None:
-                view = self._get_view_genres()
-            else:
-                view = self._get_view_albums([data], [])
-        elif item_ids[0] == Type.ALBUM:
-            view = self._get_view_album(data)
-        elif item_ids[0] == Type.YEARS:
-            if data is None:
-                view = self._get_view_albums_decades()
-            else:
-                view = self._get_view_albums_years(data)
-        elif item_ids[0] == Type.PLAYLISTS:
-            view = self._get_view_playlists([] if data is None else data)
-        elif item_ids[0] == Type.RADIOS:
-            view = self._get_view_radios()
-        elif item_ids[0] == Type.EQUALIZER:
-            from lollypop.view_equalizer import EqualizerView
-            view = EqualizerView()
-        elif item_ids[0] in [Type.SETTINGS,
-                             Type.SETTINGS_APPEARANCE,
-                             Type.SETTINGS_BEHAVIOUR,
-                             Type.SETTINGS_COLLECTIONS,
-                             Type.SETTINGS_WEB,
-                             Type.SETTINGS_DEVICES]:
-            view = self._get_view_settings(item_ids[0])
-        elif item_ids[0] == Type.ALL:
-            view = self._get_view_albums(item_ids, [])
-        elif item_ids[0] == Type.COMPILATIONS:
-            view = self._get_view_albums([], item_ids)
-        elif item_ids[0] == Type.ARTISTS:
-            # Here we handle static items for RoundedArtistView
-            if data and data[0] < 0:
-                self.show_view(data)
-                return
-            elif data is None:
-                view = self._rounded_artists_view
-            else:
-                view = self._get_view_artists(item_ids, data)
-        else:
-            view = self._get_view_artists([], item_ids)
+        view = None
+        if item_ids:
+            if item_ids[0] in [Type.POPULARS,
+                               Type.LOVED,
+                               Type.RECENTS,
+                               Type.NEVER,
+                               Type.RANDOMS,
+                               Type.WEB]:
+                view = self._get_view_albums(item_ids, [])
+            elif item_ids[0] == Type.SEARCH:
+                view = self.get_view_search(data)
+            elif item_ids[0] == Type.INFO:
+                view = self._get_view_info()
+            elif item_ids[0] == Type.DEVICE_ALBUMS:
+                view = self._get_view_device_albums(data)
+            elif item_ids[0] == Type.DEVICE_PLAYLISTS:
+                view = self._get_view_device_playlists(data)
+            elif item_ids[0] == Type.GENRES:
+                if data is None:
+                    view = self._get_view_genres()
+                else:
+                    view = self._get_view_albums([data], [])
+            elif item_ids[0] == Type.ALBUM:
+                view = self._get_view_album(data)
+            elif item_ids[0] == Type.YEARS:
+                if data is None:
+                    view = self._get_view_albums_decades()
+                else:
+                    view = self._get_view_albums_years(data)
+            elif item_ids[0] == Type.PLAYLISTS:
+                view = self._get_view_playlists([] if data is None else data)
+            elif item_ids[0] == Type.RADIOS:
+                view = self._get_view_radios()
+            elif item_ids[0] == Type.EQUALIZER:
+                from lollypop.view_equalizer import EqualizerView
+                view = EqualizerView()
+            elif item_ids[0] in [Type.SETTINGS,
+                                 Type.SETTINGS_APPEARANCE,
+                                 Type.SETTINGS_BEHAVIOUR,
+                                 Type.SETTINGS_COLLECTIONS,
+                                 Type.SETTINGS_WEB,
+                                 Type.SETTINGS_DEVICES]:
+                view = self._get_view_settings(item_ids[0])
+            elif item_ids[0] == Type.ALL:
+                view = self._get_view_albums(item_ids, [])
+            elif item_ids[0] == Type.COMPILATIONS:
+                view = self._get_view_albums([], item_ids)
+            elif item_ids[0] == Type.ARTISTS:
+                # Here we handle static items for RoundedArtistView
+                if data and data[0] < 0:
+                    self.show_view(data)
+                    return
+                elif data is None:
+                    view = self._rounded_artists_view
+        if view is None:
+            view = self._get_view_artists(item_ids, data)
         view.show()
         self._stack.add(view)
         if switch:
@@ -123,15 +121,16 @@ class ViewsContainer:
         """
         if App().player.queue and not view_type & ViewType.FULLSCREEN:
             from lollypop.view_queue import QueueView
-            view = QueueView(view_type)
+            view = QueueView(view_type | self._view_type)
             view.populate()
         elif App().player.playlist_ids:
             from lollypop.view_playlists import PlaylistsView
-            view = PlaylistsView(App().player.playlist_ids, view_type)
+            view = PlaylistsView(App().player.playlist_ids,
+                                 view_type | self._view_type)
             view.populate(App().player.playlist_tracks)
         else:
             from lollypop.view_current_albums import CurrentAlbumsView
-            view = CurrentAlbumsView(view_type)
+            view = CurrentAlbumsView(view_type | self._view_type)
             view.populate(App().player.albums)
         view.set_margin_top(MARGIN_SMALL)
         view.set_margin_start(MARGIN_SMALL)
@@ -196,17 +195,6 @@ class ViewsContainer:
                 items += App().albums.get_ids([], genre_ids)
         return items
 
-    def show_artist_view(self, artist_ids):
-        """
-            Go to artist view
-            @param artist_ids as [int]
-        """
-        if App().settings.get_value("show-sidebar") and\
-                not App().window.is_adaptive:
-            App().window.container.show_artists_albums(artist_ids)
-        else:
-            App().window.container.show_view(artist_ids)
-
 ##############
 # PROTECTED  #
 ##############
@@ -256,19 +244,22 @@ class ViewsContainer:
         if len(playlist_ids) == 1 and\
                 App().playlists.get_smart(playlist_ids[0]):
             from lollypop.view_playlists import PlaylistsView
-            view = PlaylistsView(playlist_ids, view_type)
+            view = PlaylistsView(playlist_ids, view_type | self._view_type)
             view.show()
             loader = Loader(target=load_smart, view=view)
             loader.start()
         elif playlist_ids:
             from lollypop.view_playlists import PlaylistsView
-            view = PlaylistsView(playlist_ids, view_type)
+            view = PlaylistsView(playlist_ids, view_type | self._view_type)
             view.show()
             loader = Loader(target=load, view=view)
             loader.start()
         else:
             from lollypop.view_playlists_manager import PlaylistsManagerView
-            view = PlaylistsManagerView(None, ViewType.SCROLLED)
+            view_type = ViewType.SCROLLED
+            if App().window.is_adaptive:
+                view_type |= ViewType.MEDIUM
+            view = PlaylistsManagerView(None, view_type | self._view_type)
             view.populate()
             view.show()
         return view
@@ -318,7 +309,10 @@ class ViewsContainer:
             view.populate(get_items(artist_ids, compilation_ids))
 
         from lollypop.view_artists_rounded import RoundedArtistsView
-        view = RoundedArtistsView(not static)
+        view_type = ViewType.SCROLLED
+        if App().window.is_adaptive:
+            view_type |= ViewType.MEDIUM
+        view = RoundedArtistsView(view_type | self._view_type, not static)
         self._stack.add(view)
         loader = Loader(target=load, view=view,
                         on_finished=lambda r: setup(*r))
@@ -377,7 +371,10 @@ class ViewsContainer:
                 decades.append(decade)
             return decades
         from lollypop.view_albums_decade_box import AlbumsDecadeBoxView
-        view = AlbumsDecadeBoxView(ViewType.SCROLLED)
+        view_type = ViewType.SCROLLED
+        if App().window.is_adaptive:
+            view_type |= ViewType.MEDIUM
+        view = AlbumsDecadeBoxView(self._view_type | view_type)
         view.show()
         loader = Loader(target=load, view=view)
         loader.start()
@@ -392,7 +389,8 @@ class ViewsContainer:
         view_type = ViewType.TWO_COLUMNS
         if App().window.is_adaptive:
             view_type |= ViewType.SMALL
-        view = AlbumView(album, album.artist_ids, album.genre_ids, view_type)
+        view = AlbumView(album, album.artist_ids, album.genre_ids,
+                         view_type | self._view_type)
         view.populate()
         return view
 
@@ -404,7 +402,10 @@ class ViewsContainer:
             return App().genres.get_ids()
 
         from lollypop.view_albums_genre_box import AlbumsGenreBoxView
-        view = AlbumsGenreBoxView(ViewType.SCROLLED)
+        view_type = ViewType.SCROLLED
+        if App().window.is_adaptive:
+            view_type |= ViewType.MEDIUM
+        view = AlbumsGenreBoxView(view_type | self._view_type)
         view.show()
         loader = Loader(target=load, view=view)
         loader.start()
@@ -426,7 +427,7 @@ class ViewsContainer:
         view_type = ViewType.SCROLLED
         if App().window.is_adaptive:
             view_type |= ViewType.MEDIUM
-        view = AlbumsBoxView([Type.YEARS], years, view_type)
+        view = AlbumsBoxView([Type.YEARS], years, view_type | self._view_type)
         loader = Loader(target=load, view=view)
         loader.start()
         view.show()
@@ -447,7 +448,8 @@ class ViewsContainer:
         view_type = ViewType.SCROLLED
         if App().window.is_adaptive:
             view_type |= ViewType.MEDIUM
-        view = AlbumsBoxView(genre_ids, artist_ids, view_type)
+        view = AlbumsBoxView(genre_ids, artist_ids,
+                             view_type | self._view_type)
         loader = Loader(target=load, view=view)
         loader.start()
         view.show()
@@ -467,7 +469,7 @@ class ViewsContainer:
         view_type = ViewType.SCROLLED
         if App().window.is_adaptive:
             view_type |= ViewType.MEDIUM
-        view = AlbumsBoxView([], [], view_type)
+        view = AlbumsBoxView([], [], view_type | self._view_type)
         loader = Loader(target=load, view=view)
         loader.start()
         view.show()
@@ -483,7 +485,10 @@ class ViewsContainer:
             radios = Radios()
             return radios.get_ids()
         from lollypop.view_radios import RadiosView
-        view = RadiosView()
+        view_type = ViewType.SCROLLED
+        if App().window.is_adaptive:
+            view_type |= ViewType.MEDIUM
+        view = RadiosView(view_type | self._view_type)
         loader = Loader(target=load, view=view)
         loader.start()
         view.show()
@@ -515,41 +520,29 @@ class ViewsContainer:
             view = SettingsChildView(item_id)
         return view
 
-    def _reload_navigation_view(self):
+    def _restore_state(self):
         """
-            Reload navigation view
+            Restore state
         """
         self._stack.destroy_children()
-        App().window.emit("show-can-go-back", True)
         state_one_ids = App().settings.get_value("state-one-ids")
         state_two_ids = App().settings.get_value("state-two-ids")
         state_three_ids = App().settings.get_value("state-three-ids")
-        # We do not support genres in navigation mode
         sidebar_content = App().settings.get_enum("sidebar-content")
-        if sidebar_content == SidebarContent.GENRES and\
-                state_one_ids and state_one_ids[0] >= 0 and not state_two_ids:
-            state_one_ids = []
-        # Artist id with genre off or genre and artist id
-        elif (state_two_ids and not state_one_ids) or\
-                (state_one_ids and state_one_ids[0] >= 0 and state_two_ids):
-            state_one_ids = state_two_ids
-            state_two_ids = []
-        # Be sure to have an initial artist view
-        if self._rounded_artists_view is None:
-            self._rounded_artists_view = self._get_view_artists_rounded(True)
-            self._stack.set_visible_child(self._rounded_artists_view)
         if state_one_ids and state_two_ids and state_three_ids:
             self.show_view(state_one_ids, None, False)
             album = Album(state_three_ids[0], state_one_ids, state_two_ids)
             self.show_view([Type.ALBUM], album)
         elif state_one_ids and state_two_ids:
-            self.show_view(state_one_ids, None, False)
-            self.show_view(state_one_ids, state_two_ids)
+            if sidebar_content == SidebarContent.GENRES:
+                self.show_view([Type.GENRES], None, False)
+                self.show_view([Type.GENRES], state_one_ids[0], False)
+                self.show_view(state_two_ids)
+            else:
+                self.show_view(state_one_ids, None, False)
+                self.show_view(state_one_ids, state_two_ids)
         elif state_one_ids:
             self.show_view(state_one_ids)
-        else:
-            App().window.emit("can-go-back-changed", False)
-            self._stack.set_visible_child(self._rounded_artists_view)
 
 ############
 # PRIVATE  #
