@@ -15,7 +15,7 @@ from gi.repository import Gtk, Gdk, GLib, Gio, Gst
 from datetime import datetime
 from gettext import gettext as _
 
-from lollypop.define import App, ArtSize, ArtBehaviour, Type
+from lollypop.define import App, ArtSize, ArtBehaviour, Type, ViewType
 from lollypop.controller_information import InformationController
 from lollypop.controller_playback import PlaybackController
 from lollypop.controller_progress import ProgressController
@@ -108,12 +108,9 @@ class FullScreen(Gtk.Window, AdaptiveWindow, InformationController,
         self.__back_button.set_margin_bottom(5)
         self.__back_button.show()
         self.__background_artwork = builder.get_object("background_artwork")
-        self.__container = Container()
+        self.__container = Container(ViewType.NOT_ADAPTIVE)
         self.set_stack(self.__container.stack)
-        self.add_paned(self.__container.paned_one, self.__container.list_one)
-        self.add_paned(self.__container.paned_two, self.__container.list_two)
         self.__container.show()
-        self.__container.show_sidebar(True)
         self.__sidebar = Gtk.Grid()
         self.__sidebar.set_size_request(400, -1)
         self.__sidebar.set_orientation(Gtk.Orientation.VERTICAL)
@@ -133,6 +130,8 @@ class FullScreen(Gtk.Window, AdaptiveWindow, InformationController,
         """
             Setup window for current screen
         """
+        show_sidebar = App().settings.get_value("show-sidebar")
+        self.__container.show_sidebar(show_sidebar)
         self.__signal1_id = App().player.connect("current-changed",
                                                  self.on_current_changed)
         self.__signal2_id = App().player.connect("status-changed",
