@@ -135,8 +135,9 @@ class PasswordsHelper:
         # Wait for secret
         if self.__secret is None:
             GLib.timeout_add(250, call, *args)
-        if self.__secret in [None, -1]:
             raise Exception("Waiting Secret service")
+        elif self.__secret == -1:
+            raise Exception("Error waiting for Secret service")
 
     def __on_clear_search(self, source, result, callback=None, *args):
         """
@@ -172,6 +173,7 @@ class PasswordsHelper:
                      service,
                      *args)
         else:
+            Logger.debug("PasswordsHelper: no secret!")
             callback(None, None, service, *args)
 
     def __on_secret_search(self, source, result, service, callback, *args):
@@ -193,8 +195,10 @@ class PasswordsHelper:
                                      callback,
                                      *args)
                 if not items:
+                    Logger.debug("PasswordsHelper: no items!")
                     callback(None, None, service, *args)
             else:
+                Logger.debug("PasswordsHelper: no result!")
                 callback(None, None, service, *args)
         except Exception as e:
             Logger.debug("PasswordsHelper::__on_secret_search(): %s" % e)
