@@ -222,7 +222,7 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             album_ids += App().albums.get_recents()
         # We are in randoms view, add random albums
         elif filter1_ids and filter1_ids[0] == Type.RANDOMS:
-            album_ids += App().albums.get_cached_randoms()
+            album_ids += App().albums.get_randoms()
         # We are in compilation view without genre
         elif filter1_ids and filter1_ids[0] == Type.COMPILATIONS:
             album_ids += App().albums.get_compilation_ids([])
@@ -293,7 +293,7 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
     def play_uris(self, uris):
         """
             Play uris
-            @param uri as [str]
+            @param uris as [str]
         """
         # First get tracks
         tracks = []
@@ -352,8 +352,8 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         """
         try:
             if App().settings.get_value("save-state"):
-                current_track_id = load(open(LOLLYPOP_DATA_PATH +
-                                             "/track_id.bin", "rb"))
+                self._current_playback_track = Track(
+                    load(open(LOLLYPOP_DATA_PATH + "/track_id.bin", "rb")))
                 self.set_queue(load(open(LOLLYPOP_DATA_PATH +
                                          "/queue.bin", "rb")))
                 albums = load(open(LOLLYPOP_DATA_PATH + "/Albums.bin", "rb"))
@@ -364,11 +364,11 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
                 if playlist_ids and playlist_ids[0] == Type.RADIOS:
                     radios = Radios()
                     track = Track()
-                    name = radios.get_name(current_track_id)
-                    uri = radios.get_uri(current_track_id)
+                    name = radios.get_name(self._current_playback_track.id)
+                    uri = radios.get_uri(self._current_playback_track.id)
                     track.set_radio(name, uri)
                     self.load(track, is_playing)
-                elif App().tracks.get_uri(current_track_id) != "":
+                elif self._current_playback_track.uri:
                     if albums:
                         if was_party:
                             App().lookup_action("party").change_state(
@@ -379,10 +379,10 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
                                                 "/Albums.bin",
                                                 "rb"))
                         # Load track from player albums
-                        current_track = Track(current_track_id)
-                        index = self.album_ids.index(current_track.album.id)
+                        index = self.album_ids.index(
+                            self._current_playback_track.album.id)
                         for track in self._albums[index].tracks:
-                            if track.id == current_track_id:
+                            if track.id == self._current_playback_track.id:
                                 self._load_track(track)
                                 break
                     else:
@@ -391,7 +391,7 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
                         for playlist_id in playlist_ids:
                             tracks += App().playlists.get_tracks(playlist_id)
                             for track in tracks:
-                                if track.id == current_track_id:
+                                if track.id == self._current_playback_track.id:
                                     break
                         self.populate_playlist_by_tracks(
                             tracks, playlist_ids, track)
@@ -441,7 +441,6 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
     def set_next(self):
         """
             Play next track
-            @param sql as sqlite cursor
         """
         if self.current_track.id == Type.RADIOS or\
                 self._current_track.id == self.__stop_after_track_id:
@@ -474,17 +473,23 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         """
             Skip current album
         """
-        # In party or shuffle, just update next track
-        if self.is_party or\
-                App().settings.get_enum("shuffle") == Shuffle.TRACKS:
-            self.set_next()
-            # We send this signal to update next popover
-            self.emit("queue-changed")
-        elif self._current_track.id is not None:
-            self.pause()
-            self.load(self._current_track.album.tracks[-1])
-            self.set_next()
-            self.next()
+        try:
+            # In party or shuffle, just update next track
+            if self.is_party or\
+                    App().settings.get_enum("shuffle") == Shuffle.TRACKS:
+                self.set_next()
+                # We send this signal to update next popover
+                self.emit("queue-changed")
+            elif self._current_track.id is not None:
+                index = self.album_ids.index(
+                    App().player._current_playback_track.album.id)
+                if index + 1 >= len(self._albums):
+                    next_album = self._albums[0]
+                else:
+                    next_album = self._albums[index + 1]
+                self.load(next_album.tracks[0])
+        except Exception as e:
+            Logger.error("Player::skip_album(): %s" % e)
 
     def update_crossfading(self):
         """
@@ -561,15 +566,14 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         """
             On stream start, set next and previous track
         """
-        if self._current_track.id is not None and self._current_track.id >= 0:
-            ShufflePlayer._on_stream_start(self, bus, message)
         if self.track_in_queue(self._current_track):
             self.remove_from_queue(self._current_track.id)
         else:
             self._current_playback_track = self._current_track
+        ShufflePlayer._on_stream_start(self, bus, message)
+        BinPlayer._on_stream_start(self, bus, message)
         self.set_prev()
         self.set_next()
-        BinPlayer._on_stream_start(self, bus, message)
 
 #######################
 # PRIVATE             #
